==> template-tool-cli-1.0.3.tgz: package/bin/template-tool.js <==
#!/usr/bin/env node
// 必须在文件头添加如上内容指定运行环境为node
// npm i -g san-cli
// npm link
// npm unlink
// npm config get registry  npm config set registry https://registry.npmjs.org/
// npm publish
// ./node_modules/.bin/template-tool opt init

const program = require('commander') // 命令行工具
const chalk = require('chalk') // 命令行输出样式美化
const { version } = require('../package.json')
const inquirer = require('inquirer') // 命令行答询
const ora = require('ora') // 命令行中加载状态标识
const { promisify } = require('util')
const figlet = promisify(require('figlet'))
const path = require('path')
const fse = require('fs-extra')
const GitClone = require('./gitClone')

const templateConfig = {
  'template-v4.5-plus': {
    repositoryName: 'template-v4.5-plus',
    remoteRepositoryPath: '-b master --single-branch --depth 1 http://ezfeTeam:ezfeTeam@192.168.1.141:10080/ezfe/template-v4.5-plus.git'
  },
  'template-v4.5-plus-cssvar': {
    repositoryName: 'template-v4.5-plus',
    remoteRepositoryPath: '-b master-cssvar --single-branch --depth 1 http://ezfeTeam:ezfeTeam@192.168.1.141:10022/ezfe/template-v4.5-plus.git'
  },
  iconFont: {
    repositoryName: 'iconFont',
    remoteRepositoryPath: '-b master --single-branch --depth 1 http://ezfeTeam:ezfeTeam@192.168.1.141:10022/ezfe/iconFont.git'
  }
}
let setting = [
  {
    templateName: 'template-v4.5-plus',
    name: 'vue3模版',
    description: 'vue3模版',
    detail: '',
    copyFile: {
      'tools/*': 'tools',
      'public/static/*': 'public/static',
      'package.json': 'package.json'
    },
    options: {
      init: true,
      update: true
    },
    default: true
  },
  {
    templateName: 'template-v4.5-plus-cssvar',
    name: 'vue3模版-CSS变量',
    description: 'vue3模版-CSS变量',
    detail: '',
    copyFile: {
      'tools/*': 'tools',
      'public/static/*': 'public/static',
      'package.json': 'package.json'
    },
    options: {
      init: true,
      update: true
    },
    default: true
  },
  {
    templateName: 'iconFont',
    name: '字体图标',
    description: '字体图标库',
    detail: '',
    copyFile: {
      'fonts/*': 'public/static/assets/fonts',
      'ezicon.css': 'public/static/assets',
      'ezicon-new.css': 'public/static/assets'
    },
    options: {
      init: false,
      update: true
    },
    default: true
  },
  {
    templateName: 'iconFont',
    name: '字体图标 - doc',
    description: '字体图标库 Doc 项目',
    detail: '',
    copyFile: {
      'fonts/*': 'static/assets/fonts',
      'ezicon.css': 'static/assets',
      'ezicon-new.css': 'static/assets'
    },
    options: {
      init: false,
      update: true
    },
    default: true
  },
  {
    templateName: 'iconFont',
    name: '字体图标 - apm',
    description: '字体图标库 APM 项目',
    detail: '',
    copyFile: {
      'fonts/*': 'static/fonts',
      'ezicon.css': 'static',
      'ezicon-new.css': 'static'
    },
    options: {
      init: false,
      update: true
    },
    default: true
  }
]

const initConfig = function (opt, userConfig = []) {
  setting = setting.concat(userConfig)
  const sourcePick = setting.map((item, index) => {
    return {
      name: `${item.name}（${item.templateName}）`,
      value: {
        name: item.name,
        detail: item.detail,
        description: item.description,
        copyFile: item.copyFile,
        options: item.options,
        default: item.default,
        ...templateConfig[item.templateName]
      }
    }
  })
  const initSetting = []
  const updateSetting = []
  for (let i = 0; i < sourcePick.length; i++) {
    if (sourcePick[i].value.options.init) {
      initSetting.push(sourcePick[i])
    }
    if (sourcePick[i].value.options.update) {
      updateSetting.push(sourcePick[i])
    }
  }
  if (opt === 'init') {
    return {
      type: 'list',
      message: '请选择拉取的模版类型:',
      name: 'type',
      choices: initSetting
    }
  } else {
    return {
      type: 'list',
      message: '请选择拉取的模版类型:',
      name: 'type',
      choices: updateSetting
    }
  }
}

const option = ['init', 'update']
program.version(version, '-v, --version')

program.command('opt <opt>')
  .option('-show')
  .description('输入项目名称，初始化项目模版')
  .action(async (opt, cmd) => {
    if (!opt || !option.includes(opt)) {
      console.log(chalk.red(`${opt} 该类型暂不支持...`))
      process.exit(1)
    }
    const data = await figlet(`welcome   ${opt}`)
    console.log(chalk.green(data))
    // console.log(templateName, projectName)
    // let downloadUrl = templates[templateName].downloadUrl
    const projectPath = path.join(process.cwd())
    let userConfig = []
    const userConfigPath = path.join(process.cwd(), 'templateToolConfig.js')
    if (fse.pathExistsSync(userConfigPath)) {
      userConfig = require(userConfigPath)
    }
    const config = initConfig(opt, userConfig)
    // spinner.succeed('项目模板下载成功')
    inquirer.prompt([config]).then(result => { // inquirer 交互问答
      if (cmd.Show) {
        console.log('您选择的模版类型信息如下：', result)
      }
      // console.log('项目初始化拷贝获取中...')
      const spinner = ora('正在下载模板...').start()
      const gitInstance = new GitClone({
        ...result.type,
        projectPath
      })
      gitInstance.download(opt).then(res => {
        if (res) {
          spinner.succeed(`${result.type.name}${result.type.description}模板下载成功`)
        } else {
          spinner.fail(`${result.type.name}${result.type.description}模板下载失败`)
        }
      }).catch(() => {
        spinner.fail(`${result.type.name}${result.type.description}模板下载失败`)
      })
    })
  })
program.parse(program.argv)

==> template-tool-cli-1.0.7.tgz: package/bin/template-tool.js <==
#!/usr/bin/env node
// 必须在文件头添加如上内容指定运行环境为node
// npm i -g san-cli
// npm link
// npm unlink
// npm config get registry  npm config set registry https://registry.npmjs.org/
// npm publish
// ./node_modules/.bin/template-tool opt init

const program = require('commander') // 命令行工具
const chalk = require('chalk') // 命令行输出样式美化
const { version } = require('../package.json')
const inquirer = require('inquirer') // 命令行答询
const ora = require('ora') // 命令行中加载状态标识
const { promisify } = require('util')
const figlet = promisify(require('figlet'))
const path = require('path')
const fse = require('fs-extra')
const GitClone = require('./gitClone')

const templateConfig = {
  'template-v4.5-plus': {
    repositoryName: 'template-v4.5-plus',
    remoteRepositoryPath: '-b master --single-branch http://ezfeTeam:ezfeTeam@192.168.1.141:10580/ezfe/template-v4.5-plus.git'
  },
  'template-v4.5-plus-cssvar': {
    repositoryName: 'template-v4.5-plus',
    remoteRepositoryPath: '-b master-cssvar --single-branch http://ezfeTeam:ezfeTeam@192.168.1.141:10580/ezfe/template-v4.5-plus.git'
  },
  iconFont: {
    repositoryName: 'iconFont',
    remoteRepositoryPath: '-b master --single-branch --depth 1 http://ezfeTeam:ezfeTeam@192.168.1.141:10580/ezfe/iconFont.git'
  },
  'ez-ui-toolkit': {
    repositoryName: 'ez-ui-toolkit',
    remoteRepositoryPath: '-b develop ssh://git@192.168.1.141:10022/ezfe-base/ez-ui-toolkit.git'
  },
  'visualization': {
    repositoryName: 'visualization',
    remoteRepositoryPath: '-b develop ssh://git@192.168.1.141:10022/ezfe/visualization.git'
  }
}
let setting = [
  {
    "templateName": "ez-ui-toolkit",
    "name": "utils-apm",
    "description": "用于apm的工具函数",
    "detail": "",
    "copyFile": {
        "src/lib/metricNames.js": "src/lib/metricNames.js",
        "src/utils/common/*": "src/utils",
    },
    "options": {
        "init": false,
        "update": true
    }
  },
  {
      "templateName": "ez-ui-toolkit",
      "name": "utils-app",
      "description": "用于custom的工具函数",
      "detail": "",
      "copyFile": {
          "src/lib/metricNames.js": "src/lib/metricNames.js",
          "src/utils/common/*": "src/utils",
      },
      "options": {
          "init": false,
          "update": true
      }
  },
  {
      "templateName": "ez-ui-toolkit",
      "name": "utils-vue3",
      "description": "用于vue3的工具函数",
      "detail": "",
      "copyFile": {
          "src/lib/metricNames.js": "src/lib/metricNames.js",
          "src/utils/*": "src/utils",
      },
      "options": {
          "init": false,
          "update": true
      }
  },
  {
      "templateName": "visualization",
      "name": "vis-4.3",
      "description": "用于apm4.3的可视化",
      "detail": "",
      "copyFile": {
          "src/components/vis/4.3/*": "src/components/vis/use",
          "src/components/vis/common/*": "src/components/vis/common",
      },
      "options": {
          "init": false,
          "update": true
      }
  },
  {
      "templateName": "visualization",
      "name": "vis-4.2",
      "description": "用于apm4.2的可视化",
      "detail": "",
      "copyFile": {
          "src/components/vis/4.2/*": "src/components/vis/use",
          "src/components/vis/common/*": "src/components/vis/common",
      },
      "options": {
          "init": false,
          "update": true
      },
      default: true
  },
  {
    templateName: 'template-v4.5-plus',
    name: 'vue3模版',
    description: 'vue3模版',
    detail: '',
    copyFile: {
      'tools/*': 'tools',
      'public/static/*': 'public/static',
      'package.json': 'package.json'
    },
    options: {
      init: true,
      update: true
    },
    default: true
  },
  {
    templateName: 'template-v4.5-plus-cssvar',
    name: 'vue3模版-CSS变量',
    description: 'vue3模版-CSS变量',
    detail: '',
    copyFile: {
      'tools/*': 'tools',
      'public/static/*': 'public/static',
      'package.json': 'package.json'
    },
    options: {
      init: true,
      update: true
    },
    default: true
  },
  {
    templateName: 'iconFont',
    name: '字体图标',
    description: '字体图标库',
    detail: '',
    copyFile: {
      'fonts/*': 'public/static/assets/fonts',
      'ezicon.css': 'public/static/assets',
      'ezicon-new.css': 'public/static/assets'
    },
    options: {
      init: false,
      update: true
    },
    default: true
  },
  {
    templateName: 'iconFont',
    name: '字体图标 - doc',
    description: '字体图标库 Doc 项目',
    detail: '',
    copyFile: {
      'fonts/*': 'static/assets/fonts',
      'ezicon.css': 'static/assets',
      'ezicon-new.css': 'static/assets'
    },
    options: {
      init: false,
      update: true
    },
    default: true
  },
  {
    templateName: 'iconFont',
    name: '字体图标 - apm',
    description: '字体图标库 APM 项目',
    detail: '',
    copyFile: {
      'fonts/*': 'static/fonts',
      'ezicon.css': 'static',
      'ezicon-new.css': 'static'
    },
    options: {
      init: false,
      update: true
    },
    default: true
  }
]

const initConfig = function (opt, userConfig = []) {
  setting = setting.concat(userConfig)
  const sourcePick = setting.map((item, index) => {
    return {
      name: `${item.name}（${item.templateName}）`,
      value: {
        name: item.name,
        detail: item.detail,
        description: item.description,
        copyFile: item.copyFile,
        options: item.options,
        default: item.default,
        ...templateConfig[item.templateName]
      }
    }
  })
  const initSetting = []
  const updateSetting = []
  for (let i = 0; i < sourcePick.length; i++) {
    if (sourcePick[i].value.options.init) {
      initSetting.push(sourcePick[i])
    }
    if (sourcePick[i].value.options.update) {
      updateSetting.push(sourcePick[i])
    }
  }
  if (opt === 'init') {
    return {
      type: 'list',
      message: '请选择拉取的模版类型:',
      name: 'type',
      choices: initSetting
    }
  } else {
    return {
      type: 'list',
      message: '请选择拉取的模版类型:',
      name: 'type',
      choices: updateSetting
    }
  }
}

const option = ['init', 'update']
program.version(version, '-v, --version')

program.command('opt <opt>')
  .alias('o')
  .option('-show')
  .description('输入项目名称，初始化项目模版')
  .action(async (opt, cmd) => {
    if (!opt || !option.includes(opt)) {
      console.log(chalk.red(`${opt} 该类型暂不支持...`))
      process.exit(1)
    }
    const data = await figlet(`welcome   ${opt}`)
    console.log(chalk.green(data))
    // console.log(templateName, projectName)
    // let downloadUrl = templates[templateName].downloadUrl
    const projectPath = path.join(process.cwd())
    let userConfig = []
    const userConfigPath = path.join(process.cwd(), 'templateToolConfig.js')
    if (fse.pathExistsSync(userConfigPath)) {
      userConfig = require(userConfigPath)
    }
    const config = initConfig(opt, userConfig)
    // spinner.succeed('项目模板下载成功')
    inquirer.prompt([config]).then(result => { // inquirer 交互问答
      if (cmd.Show) {
        console.log('您选择的模版类型信息如下：', result)
      }
      // console.log('项目初始化拷贝获取中...')
      const spinner = ora('正在下载模板...').start()
      const gitInstance = new GitClone({
        ...result.type,
        projectPath
      })
      gitInstance.download(opt).then(res => {
        if (res) {
          spinner.succeed(`${result.type.name}${result.type.description}模板下载成功`)
        } else {
          spinner.fail(`${result.type.name}${result.type.description}模板下载失败`)
        }
      }).catch(() => {
        spinner.fail(`${result.type.name}${result.type.description}模板下载失败`)
      })
    })
  })
program.parse(program.argv)
